tesseract_ecs v0.3.1 Tesseract.ECS.Scene View Source
Link to this section Summary
Functions
Returns a specification to start this module under a supervisor
Invoked in order to access the value stored under key in the given term term
Invoked in order to access the value stored under key in the given term term,
defaulting to default if not present
Invoked in order to access the value under key and update it at the same time
Invoked when the server is started. start_link/3 or start/3 will
block until it returns
Invoked to “pop” the value under key out of the given data structure
Link to this section Functions
Returns a specification to start this module under a supervisor.
See Supervisor.
Invoked in order to access the value stored under key in the given term term.
This function should return {:ok, value} where value is the value under
key if the key exists in the term, or :error if the key does not exist in
the term.
Many of the functions defined in the Access module internally call this
function. This function is also used when the square-brackets access syntax
(structure[key]) is used: the fetch/2 callback implemented by the module
that defines the structure struct is invoked and if it returns {:ok,
value} then value is returned, or if it returns :error then nil is
returned.
See the Map.fetch/2 and Keyword.fetch/2 implementations for examples of
how to implement this callback.
Callback implementation for Access.fetch/2.
Invoked in order to access the value stored under key in the given term term,
defaulting to default if not present.
This function should return the value under key in term if there’s
such key, otherwise default.
For most data structures, this can be implemented using fetch/2 internally;
for example:
def get(structure, key, default) do
case fetch(structure, key) do
{:ok, value} -> value
:error -> default
end
end
See the Map.get/3 and Keyword.get/3 implementations for examples of
how to implement this callback.
Callback implementation for Access.get/3.
Invoked in order to access the value under key and update it at the same time.
The implementation of this callback should invoke fun with the value under
key in the passed structure data, or with nil if key is not present in it.
This function must return either {get_value, update_value} or :pop.
If the passed function returns {get_value, update_value},
the return value of this callback should be {get_value, new_data}, where:
get_valueis the retrieved value (which can be operated on before being returned)update_valueis the new value to be stored underkeynew_dataisdataafter updating the value ofkeywithupdate_value.
If the passed function returns :pop, the return value of this callback
must be {value, new_data} where value is the value under key
(or nil if not present) and new_data is data without key.
See the implementations of Map.get_and_update/3 or Keyword.get_and_update/3
for more examples.
Callback implementation for Access.get_and_update/3.
Invoked when the server is started. start_link/3 or start/3 will
block until it returns.
args is the argument term (second argument) passed to start_link/3.
Returning {:ok, state} will cause start_link/3 to return
{:ok, pid} and the process to enter its loop.
Returning {:ok, state, timeout} is similar to {:ok, state}
except handle_info(:timeout, state) will be called after timeout
milliseconds if no messages are received within the timeout.
Returning {:ok, state, :hibernate} is similar to
{:ok, state} except the process is hibernated before entering the loop. See
c:handle_call/3 for more information on hibernation.
Returning :ignore will cause start_link/3 to return :ignore and the
process will exit normally without entering the loop or calling c:terminate/2.
If used when part of a supervision tree the parent supervisor will not fail
to start nor immediately try to restart the GenServer. The remainder of the
supervision tree will be (re)started and so the GenServer should not be
required by other processes. It can be started later with
Supervisor.restart_child/2 as the child specification is saved in the parent
supervisor. The main use cases for this are:
- The
GenServeris disabled by configuration but might be enabled later. - An error occurred and it will be handled by a different mechanism than the
Supervisor. Likely this approach involves callingSupervisor.restart_child/2after a delay to attempt a restart.
Returning {:stop, reason} will cause start_link/3 to return
{:error, reason} and the process to exit with reason reason without
entering the loop or calling c:terminate/2.
Callback implementation for GenServer.init/1.
Invoked to “pop” the value under key out of the given data structure.
When key exists in the given structure data, the implementation should
return a {value, new_data} tuple where value is the value that was under
key and new_data is term without key.
When key is not present in the given structure, a tuple {value, data}
should be returned, where value is implementation-defined.
See the implementations for Map.pop/3 or Keyword.pop/3 for more examples.
Callback implementation for Access.pop/2.